==========
 Examples
==========

Input file
==========

.. literalinclude:: ../../../examples/notes/add-complex-example-6b5927c246456896.yaml
   :caption: examples/notes/add-complex-example-6b5927c246456896.yaml
   :language: yaml

Rendered
========

.. release-notes::
   :relnotessubdir: examples
   :earliest-version: 1.0.0
